@@ -1,5 +1,5 @@
-/**
- * Copyright 2006-2016 the original author or authors.
+/*
+ * Copyright 2006-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -21,14 +21,17 @@ import java.lang.reflect.Method;
 
 import org.objenesis.ObjenesisException;
 import org.objenesis.instantiator.ObjectInstantiator;
+import org.objenesis.instantiator.annotations.Instantiator;
+import org.objenesis.instantiator.annotations.Typology;
 
 /**
  * {@link ObjectInstantiator} for Android which creates objects using the constructor from the first
  * non-serializable parent class constructor, using internal methods on the Dalvik implementation of
  * {@link ObjectStreamClass}.
- * 
+ *
  * @author Ian Parkinson (Google Inc.)
  */
+@Instantiator(Typology.SERIALIZATION)
 public class AndroidSerializationInstantiator<T> implements ObjectInstantiator<T> {
    private final Class<T> type;
    private final ObjectStreamClass objectStreamClass;
@@ -37,7 +40,7 @@ public class AndroidSerializationInstantiator<T> implements ObjectInstantiator<T
    public AndroidSerializationInstantiator(Class<T> type) {
       this.type = type;
       newInstanceMethod = getNewInstanceMethod();
-      Method m = null;
+      Method m;
       try {
          m = ObjectStreamClass.class.getMethod("lookupAny", Class.class);
       } catch (NoSuchMethodException e) {
@@ -45,9 +48,7 @@ public class AndroidSerializationInstantiator<T> implements ObjectInstantiator<T
       }
       try {
          objectStreamClass = (ObjectStreamClass) m.invoke(null, type);
-      } catch (IllegalAccessException e) {
-         throw new ObjenesisException(e);
-      } catch (InvocationTargetException e) {
+      } catch (IllegalAccessException | InvocationTargetException e) {
          throw new ObjenesisException(e);
       }
    }
@@ -56,13 +57,7 @@ public class AndroidSerializationInstantiator<T> implements ObjectInstantiator<T
       try {
          return type.cast(newInstanceMethod.invoke(objectStreamClass, type));
       }
-      catch(IllegalAccessException e) {
-         throw new ObjenesisException(e);
-      }
-      catch(IllegalArgumentException e) {
-         throw new ObjenesisException(e);
-      }
-      catch(InvocationTargetException e) {
+      catch(IllegalAccessException | IllegalArgumentException | InvocationTargetException e) {
          throw new ObjenesisException(e);
       }
    }
@@ -74,10 +69,7 @@ public class AndroidSerializationInstantiator<T> implements ObjectInstantiator<T
          newInstanceMethod.setAccessible(true);
          return newInstanceMethod;
       }
-      catch(RuntimeException e) {
-         throw new ObjenesisException(e);
-      }
-      catch(NoSuchMethodException e) {
+      catch(RuntimeException | NoSuchMethodException e) {
          throw new ObjenesisException(e);
       }
    }
