@@ -1,5 +1,5 @@
-/**
- * Copyright 2006-2016 the original author or authors.
+/*
+ * Copyright 2006-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,15 +19,18 @@ import java.lang.reflect.Constructor;
 
 import org.objenesis.ObjenesisException;
 import org.objenesis.instantiator.ObjectInstantiator;
+import org.objenesis.instantiator.annotations.Instantiator;
+import org.objenesis.instantiator.annotations.Typology;
 
 /**
  * Instantiates a class by grabbing the no args constructor and calling Constructor.newInstance().
  * This can deal with default public constructors, but that's about it.
- * 
+ *
  * @author Joe Walnes
  * @param <T> Type instantiated
  * @see ObjectInstantiator
  */
+@Instantiator(Typology.NOT_COMPLIANT)
 public class ConstructorInstantiator<T> implements ObjectInstantiator<T> {
 
    protected Constructor<T> constructor;
