@@ -1,5 +1,5 @@
-/**
- * Copyright 2006-2016 the original author or authors.
+/*
+ * Copyright 2006-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,17 +20,20 @@ import java.lang.reflect.Method;
 
 import org.objenesis.ObjenesisException;
 import org.objenesis.instantiator.ObjectInstantiator;
+import org.objenesis.instantiator.annotations.Instantiator;
+import org.objenesis.instantiator.annotations.Typology;
 
 /**
  * Instantiates a class by using reflection to make a call to private method
  * ObjectStreamClass.newInstance, present in many JVM implementations. This instantiator will create
  * classes in a way compatible with serialization, calling the first non-serializable superclass'
  * no-arg constructor.
- * 
+ *
  * @author Leonardo Mesquita
  * @see ObjectInstantiator
  * @see java.io.Serializable
  */
+@Instantiator(Typology.SERIALIZATION)
 public class ObjectStreamClassInstantiator<T> implements ObjectInstantiator<T> {
 
    private static Method newInstanceMethod;
@@ -41,12 +44,9 @@ public class ObjectStreamClassInstantiator<T> implements ObjectInstantiator<T> {
             newInstanceMethod = ObjectStreamClass.class.getDeclaredMethod("newInstance");
             newInstanceMethod.setAccessible(true);
          }
-         catch(RuntimeException e) {
+         catch(RuntimeException | NoSuchMethodException e) {
             throw new ObjenesisException(e);
          }
-         catch(NoSuchMethodException e) {
-            throw new ObjenesisException(e);
-         }         
       }
    }
 
@@ -59,14 +59,14 @@ public class ObjectStreamClassInstantiator<T> implements ObjectInstantiator<T> {
 
    @SuppressWarnings("unchecked")
    public T newInstance() {
-	   
+
       try {
          return (T) newInstanceMethod.invoke(objStreamClass);
       }
       catch(Exception e) {
          throw new ObjenesisException(e);
       }
-      
+
    }
 
 }
