@@ -1,5 +1,5 @@
-/**
- * Copyright 2006-2016 the original author or authors.
+/*
+ * Copyright 2006-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,15 +20,18 @@ import java.lang.reflect.Method;
 
 import org.objenesis.ObjenesisException;
 import org.objenesis.instantiator.ObjectInstantiator;
+import org.objenesis.instantiator.annotations.Instantiator;
+import org.objenesis.instantiator.annotations.Typology;
 
 /**
  * Instantiates a class by making a call to internal Perc private methods. It is only supposed to
  * work on Perc JVMs. This instantiator will not call any constructors. The code was provided by
  * Aonix Perc support team.
- * 
+ *
  * @author Henri Tremblay
  * @see org.objenesis.instantiator.ObjectInstantiator
  */
+@Instantiator(Typology.STANDARD)
 public class PercInstantiator<T> implements ObjectInstantiator<T> {
 
 	private final Method newInstanceMethod;
@@ -44,13 +47,10 @@ public class PercInstantiator<T> implements ObjectInstantiator<T> {
             Boolean.TYPE);
 			newInstanceMethod.setAccessible(true);
 		}
-      catch(RuntimeException e) {
+      catch(RuntimeException | NoSuchMethodException e) {
 			throw new ObjenesisException(e);
 		}
-      catch(NoSuchMethodException e) {
-         throw new ObjenesisException(e);
-      }
-	}
+   }
 
 	@SuppressWarnings("unchecked")
    public T newInstance() {
