@@ -1,5 +1,5 @@
-/**
- * Copyright 2006-2016 the original author or authors.
+/*
+ * Copyright 2006-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,10 +15,10 @@
  */
 package org.objenesis.strategy;
 
-import org.objenesis.ObjenesisException;
-
 import java.lang.reflect.Field;
 
+import org.objenesis.ObjenesisException;
+
 /**
  * List of constants describing the currently used platform.
  *
@@ -26,9 +26,6 @@ import java.lang.reflect.Field;
  */
 public final class PlatformDescription {
 
-   /** JVM_NAME prefix for JRockit */
-   public static final String JROCKIT = "BEA";
-
    /** JVM_NAME prefix for GCJ */
    public static final String GNU = "GNU libgcj";
 
@@ -93,9 +90,8 @@ public final class PlatformDescription {
               + "JVM version=" + VM_VERSION + ", "
               + "JVM info=" + VM_INFO;
 
-      // Add the API level is it's an Android platform
-      int androidVersion = ANDROID_VERSION;
-      if(androidVersion != 0) {
+      // Add the API level if it's an Android platform
+      if(ANDROID_VERSION != 0) {
          desc += ", API level=" + ANDROID_VERSION;
       }
       desc += ")";
@@ -134,6 +130,29 @@ public final class PlatformDescription {
       return bootClasspath != null && bootClasspath.toLowerCase().contains("core-oj.jar");
    }
 
+   /**
+    * Tells if the current JVM is running Java 9 or above
+    *
+    * @return if the current JVM is Java 9 or above
+    */
+   public static boolean isAfterJigsaw() {
+      String version = PlatformDescription.SPECIFICATION_VERSION;
+      return version.indexOf('.') < 0; // No dot means the version is 9, 10, 11, ... not 1.6, 1.7, 1.8
+   }
+
+   /**
+    * Tells if the current JVM is running Java 11 or above
+    *
+    * @return if the current JVM is Java 11 or above
+    */
+   public static boolean isAfterJava11() {
+      if(!isAfterJigsaw()) {
+         return false;
+      }
+      int version = Integer.parseInt(PlatformDescription.SPECIFICATION_VERSION);
+      return version >= 11;
+   }
+
    public static boolean isGoogleAppEngine() {
       return GAE_VERSION != null;
    }
