@@ -1,5 +1,5 @@
-/**
- * Copyright 2006-2016 the original author or authors.
+/*
+ * Copyright 2006-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -40,7 +40,7 @@ public class ObjenesisExceptionTest {
       // Check null case
       e = new ObjenesisException((Throwable) null);
       assertNull(e.getCause());
-      assertEquals(null, e.getMessage());
+      assertNull(e.getMessage());
    }
 
    @Test
