@@ -1,5 +1,5 @@
-/**
- * Copyright 2006-2017 the original author or authors.
+/*
+ * Copyright 2006-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -33,22 +33,22 @@ public class MagicInstantiatorTest {
    public void before() {
       // I know it works on Hotspot and OpenJDK. Before JDK 9. Not sure on others
       assumeTrue((PlatformDescription.isThisJVM(PlatformDescription.HOTSPOT) || PlatformDescription.isThisJVM(PlatformDescription.OPENJDK))
-         && !PlatformDescription.SPECIFICATION_VERSION.equals("9")
+         && !PlatformDescription.isAfterJigsaw()
       );
    }
 
    @Test
-   public void testNewInstance() throws Exception {
-      ObjectInstantiator<EmptyClass> o1 = new MagicInstantiator<EmptyClass>(EmptyClass.class);
+   public void testNewInstance() {
+      ObjectInstantiator<EmptyClass> o1 = new MagicInstantiator<>(EmptyClass.class);
       assertEquals(EmptyClass.class, o1.newInstance().getClass());
 
-      ObjectInstantiator<EmptyClass> o2 = new MagicInstantiator<EmptyClass>(EmptyClass.class);
+      ObjectInstantiator<EmptyClass> o2 = new MagicInstantiator<>(EmptyClass.class);
       assertEquals(EmptyClass.class, o2.newInstance().getClass());
    }
 
    @Test
    public void testInternalInstantiator() {
-      ObjectInstantiator<EmptyClass> o1 = new MagicInstantiator<EmptyClass>(EmptyClass.class).getInstantiator();
+      ObjectInstantiator<EmptyClass> o1 = new MagicInstantiator<>(EmptyClass.class).getInstantiator();
       assertEquals(EmptyClass.class, o1.newInstance().getClass());
    }
 }
