@@ -1,5 +1,5 @@
-/**
- * Copyright 2006-2017 the original author or authors.
+/*
+ * Copyright 2006-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,8 +15,6 @@
  */
 package org.objenesis.tck;
 
-import java.io.IOException;
-
 import org.objenesis.ObjenesisSerializer;
 import org.objenesis.ObjenesisStd;
 
@@ -33,9 +31,8 @@ public class Main {
     * Main class of the TCK. Can also be called as a normal method from an application server.
     *
     * @param args No parameters are required
-    * @throws IOException When the TCK fails to read properties' files.
     */
-   public static void main(String[] args) throws IOException {
+   public static void main(String[] args) {
 
       TextReporter reporter = new TextReporter(System.out, System.err);
 
