@@ -1,5 +1,5 @@
-/**
- * Copyright 2006-2017 the original author or authors.
+/*
+ * Copyright 2006-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -52,7 +52,7 @@ public class TCK {
    private final Objenesis objenesisSerializer;
    private final Reporter reporter;
 
-   private final List<Candidate> candidates = new ArrayList<Candidate>();
+   private final List<Candidate> candidates = new ArrayList<>();
 
    /**
     * @param objenesisStandard Objenesis instance used to instantiate classes the standard way (no constructor called)
