@@ -1,5 +1,5 @@
-/**
- * Copyright 2006-2017 the original author or authors.
+/*
+ * Copyright 2006-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,7 +16,6 @@
 package org.objenesis.tck.features;
 
 import java.io.Externalizable;
-import java.io.IOException;
 import java.io.ObjectInput;
 import java.io.ObjectOutput;
 import java.io.Serializable;
@@ -32,12 +31,12 @@ public class ReadExternalNotCalled extends AbstractFeature {
 
    public static class ReadExternalAndAll implements Serializable, Externalizable {
       @Override
-      public void writeExternal(ObjectOutput out) throws IOException {
+      public void writeExternal(ObjectOutput out) {
          called.add("writeExternal");
       }
 
       @Override
-      public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException {
+      public void readExternal(ObjectInput in) {
          called.add("readExternal");
       }
    }
