@@ -1,5 +1,5 @@
-/**
- * Copyright 2006-2017 the original author or authors.
+/*
+ * Copyright 2006-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,4 +23,6 @@ public interface SearchWorkingInstantiatorListener {
     void instantiatorSupported(Class<?> c);
 
     void instantiatorUnsupported(Class<?> c, Throwable t);
+
+    void instantiatorNotFound(String className, Throwable t);
 }
