@@ -1,5 +1,5 @@
-/**
- * Copyright 2006-2017 the original author or authors.
+/*
+ * Copyright 2006-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -33,7 +33,12 @@ public class SystemOutListener implements SearchWorkingInstantiatorListener {
         System.out.printf(PATTERN, c.getSimpleName() + "(" + getTypology(c) + ")", "KO - " + t);
     }
 
-    private Typology getTypology(Class<?> c) {
+    @Override
+   public void instantiatorNotFound(String className, Throwable t) {
+       System.out.printf(PATTERN, className + " not found", "KO - " + t);
+   }
+
+   private Typology getTypology(Class<?> c) {
        Instantiator instantiatorAnn = c.getAnnotation(Instantiator.class);
        return instantiatorAnn == null ? Typology.UNKNOWN : instantiatorAnn.value();
     }
