@@ -1,5 +1,5 @@
-/**
- * Copyright 2006-2017 the original author or authors.
+/*
+ * Copyright 2006-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -54,15 +54,11 @@ public class ObjenesisTest {
       @Override
       public void exception(Candidate.CandidateType type, Exception exception) {
          ByteArrayOutputStream buffer = new ByteArrayOutputStream();
-         PrintStream out = new PrintStream(buffer);
-         try {
+         try (PrintStream out = new PrintStream(buffer)) {
             out.println("Exception when instantiating " + currentCandidate + " for " + type + ": ");
             exception.printStackTrace(out);
             fail(buffer.toString());
          }
-         finally {
-            out.close();
-         }
       }
 
       @Override
@@ -72,7 +68,7 @@ public class ObjenesisTest {
    }
 
    @Test
-   public void test() throws Exception {
+   public void test() {
       TCK tck = new TCK(new ObjenesisStd(), new ObjenesisSerializer(), new JUnitReporter());
       tck.runTests();
    }
