@@ -1,5 +1,5 @@
-/**
- * Copyright 2006-2016 the original author or authors.
+/*
+ * Copyright 2006-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,9 +16,19 @@
 package org.objenesis.tck;
 
 import java.io.File;
-import java.io.IOException;
 import java.io.Serializable;
 
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.objenesis.Objenesis;
+import org.objenesis.ObjenesisHelper;
+import org.ops4j.pax.exam.Configuration;
+import org.ops4j.pax.exam.Option;
+import org.ops4j.pax.exam.junit.PaxExam;
+import org.ops4j.pax.exam.spi.reactors.ExamReactorStrategy;
+import org.ops4j.pax.exam.spi.reactors.PerMethod;
+import org.w3c.dom.Document;
+
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.xpath.XPath;
@@ -26,25 +36,42 @@ import javax.xml.xpath.XPathExpression;
 import javax.xml.xpath.XPathExpressionException;
 import javax.xml.xpath.XPathFactory;
 
-import org.objenesis.Objenesis;
-import org.objenesis.ObjenesisHelper;
-import org.springframework.osgi.test.AbstractConfigurableBundleCreatorTests;
-import org.w3c.dom.Document;
+import static org.junit.Assert.*;
+import static org.ops4j.pax.exam.CoreOptions.*;
 
 /**
  * @author Henri Tremblay
  */
-public class OsgiTest extends AbstractConfigurableBundleCreatorTests implements Serializable {
+@RunWith(PaxExam.class)
+@ExamReactorStrategy(PerMethod.class)
+public class OsgiTest implements Serializable{
 
    private static final long serialVersionUID = 1L;
 
-   @Override
-   protected String[] getTestBundlesNames() {
+   @Configuration
+   public Option[] config() {
       String version = getImplementationVersion(Objenesis.class);
+      return options(
+         bundle("file:../main/target/objenesis-" + version + ".jar"),
+         junitBundles()
+      );
+   }
+
+   @Test
+   public void testCanInstantiate() {
+      assertSame(OsgiTest.class, ObjenesisHelper.newInstance(getClass()).getClass());
+   }
+
+   @Test
+   public void testCanInstantiateSerialize() {
+      assertSame(OsgiTest.class, ObjenesisHelper.newSerializableInstance(getClass()).getClass());
+   }
+
+   private String getImplementationVersion(final Class<?> c) {
+      String version = c.getPackage().getImplementationVersion();
       // Null means we are an IDE, not in Maven. So we have an IDE project dependency instead
       // of a Maven dependency with the jar. Which explains why the version is null (no Manifest
-      // since there's no jar. In that case we get the version from the pom.xml and hope the Maven
-      // jar is up-to-date in the local repository
+      // since there's no jar). In that case we get the version from the pom.xml.
       if(version == null) {
          try {
             XPathFactory xPathFactory = XPathFactory.newInstance();
@@ -67,18 +94,6 @@ public class OsgiTest extends AbstractConfigurableBundleCreatorTests implements
             throw new RuntimeException(e);
          }
       }
-      return new String[] {"org.objenesis, objenesis, " + version};
-   }
-
-   public void testCanInstantiate() throws IOException {
-      assertSame(OsgiTest.class, ObjenesisHelper.newInstance(getClass()).getClass());
-   }
-
-   public void testCanInstantiateSerialize() throws IOException {
-      assertSame(OsgiTest.class, ObjenesisHelper.newSerializableInstance(getClass()).getClass());
-   }
-
-   protected String getImplementationVersion(final Class<?> c) {
-      return c.getPackage().getImplementationVersion();
+      return version;
    }
 }
