@@ -1,5 +1,5 @@
-/**
- * Copyright 2006-2017 the original author or authors.
+/*
+ * Copyright 2006-2018 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,8 +15,6 @@
  */
 package org.objenesis.tck;
 
-import java.io.IOException;
-
 import org.junit.Test;
 import org.objenesis.Objenesis;
 import org.objenesis.instantiator.ObjectInstantiator;
@@ -47,7 +45,7 @@ public class TCKTest {
       // Given... a TCK with some candidate classes: A, B and C.
       TCK tck = new TCK(new StubbedInstantiator(), new StubbedInstantiator(), reporter) {
          @Override
-         protected void loadCandidates() throws IOException {
+         protected void loadCandidates() {
             registerCandidate(CandidateA.class, "Candidate A", Candidate.CandidateType.STANDARD);
             registerCandidate(CandidateB.class, "Candidate B", Candidate.CandidateType.STANDARD);
             registerCandidate(CandidateB.class, "Candidate B", Candidate.CandidateType.SERIALIZATION);
@@ -76,7 +74,7 @@ public class TCKTest {
       // Given... a TCK with some candidate classes: A, B and C.
       TCK tck = new TCK(new SelectiveInstantiator(), new SelectiveInstantiator(), reporter) {
          @Override
-         protected void loadCandidates() throws IOException {
+         protected void loadCandidates() {
             registerCandidate(CandidateA.class, "Candidate A", Candidate.CandidateType.STANDARD);
             registerCandidate(CandidateA.class, "Candidate A", Candidate.CandidateType.SERIALIZATION);
             registerCandidate(CandidateB.class, "Candidate B", Candidate.CandidateType.STANDARD);
